# -*- coding: utf-8 -*-

"""
Zde se nachazi globalni nastaveni modulu.
Je treba zde nastavit nektere parametry(viz dokumentace).
Nektere promene je treba doplnit na zaklade faktickeho 
stavu z Flexibee. Napriklad doplnit typy faktur.
"""

import ConfigParser
from pkg_resources import Requirement, resource_filename
import codecs


class Config(object):
	"""
	Base config class definuje zakladni metody pro praci s konfiguracnim souborem.	
	"""

	def __init__(self, config_name="flexipy/flexipy.conf"):
		self.conf = ConfigParser.SafeConfigParser()
		#use resource management api to find flexipy.conf, see docs
		filename = resource_filename(Requirement.parse("flexipy"), config_name)
		# Open the file with the correct encoding	
		try:
			with codecs.open(filename, 'r', encoding='utf-8') as f:
				self.conf.readfp(f)
		except IOError:
			raise ValueError('Konfiguracni soubor '+config_name+' neexistuje nebo jste uvedli spatnou cestu.')		

	def get_section_list(self, section_name):
		"""
		Tato privatni metoda spracuje vsechny sekce v config filu 
		na zaklade jmena sekce a vrati list obsahujici vsechny polozky.
		"""	
		result_list = []
		try:
			section_content = self.conf.items(section_name)
			for key, val in section_content:
				result_list.append(val)
		except ConfigParser.NoSectionError:
			raise ValueError("Config file neobsahuje sekci "+section_name)		
		return result_list

	def get_server_config(self):
		"""
		Tato metoda vrati dict obsahujici vsechna nastaveni tykajici se serveru. 		
		"""
		result = {}
		try:
			section_content = self.conf.items("server")
			for key, val in section_content:
				result[key]=val			
		except ConfigParser.NoSectionError:
			raise ValueError("Config file neobsahuje sekci server")		
		return result

	def get_evidence_list(self):
		return self.get_section_list('evidence')	

	def get_typy_faktury_prijate(self):
		return self.get_section_list('typ_faktury_prijate')

	def get_typy_faktury_vydane(self):
		return self.get_section_list('typ_faktury_vydane')	

	def get_typ_bank_dokladu(self):
		return self.get_section_list('typ_bank_dokladu')

	def get_typ_pohybu(self):
		return self.get_section_list('typ_pohybu')	

	def get_bankovni_ucty(self):
		return self.get_section_list('bankovni_ucty')	

	def get_typ_polozky_vydane(self):
		return self.get_section_list('typ_polozky_vydane')

	def get_typ_ucetni_operace(self):
		return self.get_section_list('typ_ucetni_operace')	



class TestingConfig(Config):
	"""
	Pro testovani staci vytvorit instanci teto tridy.
	"""

	def __init__(self):
		Config.__init__(self, config_name="flexipy/test_flexipy.conf")


# -*- coding: utf-8 -*-

import requests
import json
from .exceptions import FlexipyException
from main import Flexipy
from config import Config

class Banka(Flexipy):

	def __init__(self, conf=Config()):
		Flexipy.__init__(self, config=conf)

	def create_bank_doklad(self, kod, dat_vyst, typ_dokl=None, typ_pohybu=None, 
		bank_ucet=None, dalsi_param=None):
		"""Metoda vytvori novy bankovni doklad.
		:param kod: cislo dokladu
		:param dat_vyst: datum vystaveni
		:param typ_dokl: typ bankovniho dokladu moznosti jsou definovany v configu
		:param bank_ucet: ucet uvedeny v dokladu(moznosti v konfigu) 	
		"""
		if typ_dokl == None:
			typ_dokl = self.conf.get_typ_bank_dokladu()[0]			
		typ_dokl = 'code:'+typ_dokl 
		if typ_pohybu == None:
			typ_pohybu = self.conf.get_typ_pohybu()[0]
		if bank_ucet == None:
			bank_ucet = self.conf.get_bankovni_ucty()[0]	
		bank_ucet = 'code:'+bank_ucet
		b_item = {'kod': kod, 'datVyst': datum_vyst, 'typDokl': typ_dokl, 'typPohybuK': typ_pohybu, 'banka':bank_ucet}
		if dalsi_param != None:
			self.validate_params(dalsi_param, 'banka')
			for k,v in dalsi_param.iteritems():
				b_item[k] = v
		return self.create_evidence_item('banka',b_item)


	def get_all_bank_doklady(self, query=None, detail='summary'):
		"""Metoda vrati vsechny bankovni doklady z Flexibee.
		:param query: Pokud je uveden dotaz ve formatu jaky podporuje 
		Flexibee(viz dokumentace), vrati vyfiltrovane zaznamy na zaklade 
		dotazu.
		"""
		d = self.get_all_records('banka', query, detail)
		return d

	def get_bank_doklad(self, id, detail='summary'):
		return self.get_evidence_item(id, 'banka', detail)

	def get_bank_doklad_by_code(self, code, detail='summary'):
		return self.get_evidence_item_by_code(code, 'banka', detail)		

	def delete_bank_doklad(self, id):
		self.delete_item(id, 'banka')

	def update_bank_doklad(self, id, bank_item):
		"""Tato metoda provede update hodnot bankovniho dokladu ve Flexibee.
		Pro ukazku pouziti viz dokuentace
		Returns :tuple skladajici se z (success, result, error_message)
		:param: id: id zaznamu ktery bude zmenen
		:param bank_item: dictionary obsahujici zmeny
		"""
		return self.update_evidence_item(id, 'banka', bank_item)	


# -*- coding: utf-8 -*-

"""
Knihovna flexipy pro snadnou praci s REST API systemu Flexibee.
Pro ukazku pouziti se podivejte do dokumentace ve slozce docs.

:copyright: (c) 2012 Jakub Ječmínek.
:license: BSD, soubor LICENSE obsahuje kopii license.
"""
from .api import Faktura, Adresar, Banka



# -*- coding: utf-8 -*-

import requests
import json
from .exceptions import FlexipyException
import config

import re


class Flexipy(object):

	def __init__(self, config=config.Config()):
		"""
		Pokud neni predana jina instance je automaticky vytvoren config s defaultnimi hodnotami.		
		"""
		self.conf = config

	def send_request(self, method, endUrl, payload=''):
		"""Privatni funkce pro posilani requestu. Cast url se bere z nastaveni v config, 
		zbytek se doplni dle pozadavku. Tato funkce chyta nejzavaznejsi vyjimky definovane
		v knihovne Requests a vraci Response objekt pro dalsi zpracovani.
		Returns :r: response object z requests knihovny
		:param method: Typ HTTP metody, mozne hodnoty:(get,put,post,delete)
		:param endUrl: koncova cast url, zavisla na konkretnim requestu 
		:param payload: Data v requestu
		"""
		try:
			server_settings = self.conf.get_server_config()
			url = str(server_settings['url'])
			username = str(server_settings['username'])
			password = str(server_settings['password'])
			if str(server_settings['verify'])=='true':
				verify=True
			else:
				verify=False

			r = requests.request(method=method, url=str(url)+endUrl, data=payload, auth=(username, password), verify=verify)	
			if r.status_code == 401:
				raise FlexipyException("Nemate opravneni provest tuto operaci.")
			elif r.status_code == 402:
				raise FlexipyException("Platba vyzadovana, REST API neni aktivni.")
			elif r.status_code == 403:
				raise FlexipyException("Zakazana operace. Vase licence zrejme neumoznuje tuto operaci.")	
			elif r.status_code == 500:
				raise FlexipyException("Server error, zrejme je neco spatne se serverem na kterem je Flexibee.")							
		except requests.exceptions.ConnectionError as e:
			raise FlexipyException("Connection error "+str(e))
		else:
			return r

	def prepare_data(self, evidence, data):
		'''Tato funkce pripravuje data na odeslani. Prida casti vyzadovane komunikacnim formatem 
		Flexibee a vrati JSON k odeslani. 
		'''		
		winstrom = {'winstrom':{evidence:[data]}}
		return json.dumps(winstrom)


	def get_all_records(self, evidence, query=None, detail='summary'):
		'''Vytvori a odesle pozadavek k ziskani vsech zaznamu z pozadovane evidence.
		Returns :list: contatining all records

		:param evidence: podporovane evidence se nachazi v config.evidence_list
		:param query: dotaz ktey filtruje zaznamy
		:param detail: uroven zobrazeni detailu(kolik polozek daneho zaznamu se vypise)
		defaultni hodnota je summary. Dalsi moznosi je id(vypise pouze id zaznamu) a full(kompletni vypis)
		'''
		re.sub(r'\s', '', evidence) #remove all wihtespaces	
		if query == None:
			r = self.send_request(method='get', endUrl=evidence+'.json?detail='+detail)
		else:
			#pouzij query pro filtrovani
			#TODO: nejakym zpusobem zvaliduj query
			r = self.send_request(method='get', endUrl=evidence+'/('+query+').json?detail='+detail)	
		return self.process_response(r, evidence)

	def get_evidence_property_list(self, evidence):
		"""Tato funkce vraci seznam polozek danne evidence. Tyto polozky jsou 
		parsovane z Flexibee.
		:param evidence: identifikuje evidenci jejiz seznam polozek chceme stahnout
		"""
		result = {}
		r = self.send_request(method='get', endUrl=evidence+'/properties.json')
		d = r.json()	
		return d['properties']['property']		

	def prepare_error_messages(self, e):	
		"""Pomocna funkce pro vytvareni chybovych zprav.
		Tyto chybove zpravy se se prebiraji z odpovedi kterou
		posila v pripade neuspechu Flexibee.
		"""
		error_messages = []
		for error in e:
			error_messages.append(error['message'])
		return error_messages	

	def process_response(self, response, evidence=None):
		"""Pote co Flexibee vytvori novy zaznam v nejake evidenci, vrati
		odpoved obsahujici urcite informace. Tato funkce zpracuje odpoved a vratu 
		jeji obsah jako dictionary.	Odstrani take nepotrebne casti. 
		:param response: Response objekt vraceny z Flexibee
		"""
		if evidence == None:
			d = response.json()
			dictionary = d['winstrom']
			return dictionary
		else:
			d = response.json()
			if len(d['winstrom'][evidence])==1:
				dictionary = d['winstrom'][evidence][0]	
				return dictionary
			else:
				list_of_items = d['winstrom'][evidence]
				return list_of_items	

	def delete_item(self, id, evidence):
		"""Smaze zaznam v evidenci na zaklade id.
		:param id: identifikuje zaznam(Flexibee identifikator nebo pripadne kod)
		:param evidence: identifikuje v ktere evidenci se zaznam nachazi
		"""
		r = self.send_request(method='delete', endUrl=evidence+'/'+str(id)+'.json')
		if r.status_code not in (200,201):
			if r.status_code == 404:
				raise FlexipyException("Zaznam s id="+str(id)+" nebyl nalezen.")			
			else:
				raise FlexipyException("Neznama chyba.")								

	def get_evidence_item(self, id, evidence, detail='summary'):
		"""Ziskej zaznam z evidence na zaklade id.
		Vraci zaznam jako dictionary pro dalsi zpracovani.
		:param id: id zaznamu(Flexibee identifikator nebo pripadne kod)
		:param evidence: identifikuje v ktere evidenci se zaznam nachazi
		:param detail: uroven zobrazeni detailu(kolik polozek daneho zaznamu se vypise)
		defaultni hodnota je summary. Dalsi moznosi je id(vypise pouze id zaznamu) a full(kompletni vypis)		
		"""		
		r = self.send_request(method='get', endUrl=evidence+'/'+str(id)+'.json?detail='+detail)
		if r.status_code not in (200,201):
			if r.status_code == 404:
				raise FlexipyException("Zaznam s id="+str(id)+" nebyl nalezen.")			
			else:
				raise FlexipyException("Neznama chyba.")	
		else:		
			dictionary = self.process_response(r, evidence=evidence)
			return dictionary

	def get_evidence_item_by_code(self, kod, evidence, detail='summary'):
		"""Ziskej zaznam z evidence na zaklade polozky kod.
		Vraci zaznam jako dictionary pro dalsi zpracovani.
		:param kod: kod zaznamu(Flexibee polozka kod)
		:param evidence: identifikuje v ktere evidenci se zaznam nachazi	
		:param detail: uroven zobrazeni detailu(kolik polozek daneho zaznamu se vypise)
		defaultni hodnota je summary. Dalsi moznosi je id(vypise pouze id zaznamu) a full(kompletni vypis)	
		"""		
		r = self.send_request(method='get', endUrl=evidence+"/(kod='"+kod+"').json?detail="+detail)
		if r.status_code not in (200,201):
			raise FlexipyException("Neznama chyba.")	
		else:		
			dictionary = self.process_response(r, evidence=evidence)
			#pokud neni prazdne
			if dictionary:
				return dictionary
			else:
				raise FlexipyException("Zaznam s kodem="+str(kod)+" nebyl nalezen.")	

	def proved_sparovani_plateb(self):
		"""
		Provede automaticke sparovani plateb s fakturami.
		"""		
		r = self.send_request(method='post', endUrl='banka/automaticke-parovani.json')
		if r.status_code not in (200,201):
			raise FlexipyException("Neznama chyba.")

	def create_evidence_item(self, evidence, data):
		"""Privatni funkce pro vytvareni novych zaznamu v evidenci.
		Returns :tuple skladajici se z (success, result_id, error_message)
		:param evidence: evidence for new item
		:param data: JSON reprezebtace dat vytvareneho zaznamu
		"""	
		data = self.prepare_data(evidence, data)
		r = self.send_request(method='put', endUrl=evidence+'.json', payload=data)
		d = self.process_response(r)
		if d['success'] == 'true':
			id = int(d['results'][0]['id'])
			return (True, id, None)
		else:
			e = d['results'][0]['errors']
			error_messages = self.prepare_error_messages(e)
			return (False, None, error_messages) 

	def update_evidence_item(self, id, evidence, data):
		"""Function for updating already created evidence item.
		Returns :tuple consisting of (success, result, error_message)
		:param id: id(Flexibee identificator) of item to be changed
		:param evidence: evidence containing item which we want to update(change)
		:param data: dictionary containing fields which we want to update
		"""
		data = self.prepare_data(evidence, data)
		r = self.send_request(method='put', endUrl=evidence+'/'+str(id)+'.json', payload=data)
		d = self.process_response(r)
		if d['success'] == 'true':
			id = int(d['results'][0]['id'])
			return (True, id, None)
		else:
			e = d['results'][0]['errors']
			error_messages = self.prepare_error_messages(e)
			return (False, None, error_messages) 

	def validate_params(self, params, evidence):
		"""Tato funkce validuje parametry ktere zadal uzivatel jako dodatecne polozky 
		evidence.
		V pripade chybi vyhodi FlexipyException
		:param params: dictionary obsahujici dodatecne polozky
		:param evidence: typ evidence pro ktery se ma provest validace
		"""
		template_dict = self.get_template_dict(evidence, True)
		invalid_params = ''
		for key in params:
			if key not in template_dict:
				invalid_params += key + ', '			
		if len(invalid_params) > 0:
			raise FlexipyException('Dalsi parametry: '+invalid_params+'nejsou validni')

	def get_template_dict(self, evidence, complete=False):
		"""This function creates tepmlate dictionary for evidence.
		This is usefull for creation of evidence items.
		:param evidence: evidence for which will be created template
		:param complete: if True return dict with all params
		"""
		if evidence not in self.conf.get_evidence_list():
			raise ValueError('evidence arg is valid only for' +str(self.conf.get_evidence_list().evidence_list))
		#start parsing properties
		property_list = self.get_evidence_property_list(evidence)
		result={}
		if complete == False:
			for property in property_list:
			#every property is dictionary
				if property['isWritable'] == 'true' and property['mandatory']=='true':
					property_name = property['propertyName']	
					result[property_name] = ''
		else:		
			for property in property_list:
				#every property is dictionary
				if property['isWritable'] == 'true':
					property_name = property['propertyName']	
					result[property_name] = ''

		return result	


	def get_evidence_pdf(self, evidence, id):
		"""Tato funkce vrati pdf evidence s id v argumentu funkce 
		v binary podobe. TODO: checkovat ktere evidence lze takto tisknout
		Retuns: pdf v binary
		:params evidence: evidence kterou chceme vytisknout (napr. faktura-vydana)
		:params id: id evidence	
		"""	
		r = self.send_request(method='get', endUrl=evidence+'/'+str(id)+'.pdf')
		if r.status_code not in (200,201):
			if r.status_code == 404:
				raise FlexipyException("Zaznam s id="+str(id)+" nebyl nalezen.")			
			else:
				raise FlexipyException("Neznama chyba.")	
		else:				
			return r.content




# -*- coding: utf-8 -*-

import requests
import json
from .exceptions import FlexipyException
from main import Flexipy
from config import Config

class Faktura(Flexipy):

	def __init__(self, conf=Config()):
		Flexipy.__init__(self, config=conf)

	def get_all_vydane_faktury(self, query=None, detail='summary'):
		"""Metoda vrati vsechny vydane faktury z Flexibee.
		:param query: Pokud je uveden dotaz ve formatu jaky podporuje 
		Flexibee(viz dokumentace), vrati vyfiltrovane zaznamy na zaklade 
		dotazu.
		"""
		d = self.get_all_records('faktura-vydana', query, detail)
		return d

	def get_all_prijate_faktury(self, query=None, detail='summary'):
		"""Metoda vrati vsechny prijate faktury z Flexibee.
		:param query: Pokud je uveden dotaz ve formatu jaky podporuje 
		Flexibee(viz dokumentace), vrati vyfiltrovane zaznamy na zaklade 
		dotazu.
		"""
		d = self.get_all_records('faktura-prijata', query, detail)
		return d


	def create_vydana_faktura(self, kod, var_sym, datum_vyst, zdroj_pro_sklad=False, 
		typ_dokl=None, dalsi_param=None, polozky_faktury=None):
		"""Tato metoda vytvori novou vydanou fakturu ve Flexibee 
		:param kod: interni cislo
		:param var_sym: variabilni symbol faktury
		:param datum_vyst: datum vystaveni faktury format datumu(2013-02-28)
		:param zdroj_pro_sklad: True nebo False zda je zdrojem pro skladove zaznamy 
		:param typ_dokl: mozne hodnoty se nachazi v config.typ_faktury_vydane
		:param dalsi_param:  dalsi nepovinne paramerty viz dokumentace Flexibee
		:param polozky_faktury: polozky fakturz jsou list obsahujici jednotlive polozky
		Returns :tuple skladajici se z (success, result, error_message)
		"""	
		#doplneni vyzadovano flexibee
		if typ_dokl == None:
			typ_dokl = self.conf.get_typy_faktury_vydane()[0]
		typ_dokl = 'code:'+typ_dokl 
		#dopleni datumu na pozadovany format
		datum_vyst += '+01:00'
		invoice = {'kod':kod, 'varSym':var_sym, 'datVyst':datum_vyst,'zdrojProSkl':zdroj_pro_sklad, 'typDokl':typ_dokl}
		if dalsi_param != None:
			self.validate_params(dalsi_param, 'faktura-vydana')
			for k,v in dalsi_param.iteritems():
				invoice[k] = v			
		if polozky_faktury != None:		
			invoice['bezPolozek'] = False
			inv_items = []
			for it in polozky_faktury:
				self.validate_params(it, 'faktura-vydana-polozka')
				inv_items.append(it)
			invoice['polozkyFaktury']= inv_items
		return self.create_evidence_item('faktura-vydana',invoice)
		

	def create_prijata_faktura(self, kod, var_sym, cislo_dosle, datum_splat, 
		datum_vyst, zdroj_pro_sklad=False, typ_dokl=None, 
		dalsi_param=None, polozky_faktury=None):
		"""Tato metoda zaznamena novou prijatou fakturu ve Flexibee 
		:param kod: interni cislo
		:param var_sym: variabilni symbol faktury
		:param datum_splat: datum splatnosti faktury format datumu(2013-02-28)
		:param datum_vyst: datum vystaveni faktury format datumu(2013-02-28)
		:param zdroj_pro_sklad: True nebo False zda je zdrojem pro skladove zaznamy 
		:param typ_dokl: mozne hodnoty se nachazi v config.typ_faktury_prijate
		:param dalsi_param:  dalsi nepovinne paramerty viz dokumentace Flexibee
		:param polozky_faktury: polozky fakturz jsou list obsahujici jednotlive polozky
		Returns :tuple skladajici se z (success, result, error_message)
		kde success = True/False
		"""	
		if typ_dokl == None:
			typ_dokl = self.conf.get_typy_faktury_prijate()[0]
		typ_dokl = 'code:'+typ_dokl 
		datum_splat+= '+01:00'
		datum_vyst += '+01:00'
		invoice = {'datSplat': datum_splat, 'kod': kod, 'zdrojProSkl': zdroj_pro_sklad, 'datVyst': datum_vyst, 'varSym': var_sym, 'cisDosle': cislo_dosle, 'typDokl': typ_dokl}
		if dalsi_param != None:
			self.validate_params(dalsi_param, 'faktura-prijata')
			for k,v in dalsi_param.iteritems():
				invoice[k] = v			
		if polozky_faktury != None:		
			#TODO pouzij __validate_params na validaci polozek
			invoice['bezPolozek'] = False
			inv_items = []
			for it in polozky_faktury:
				self.validate_params(it, 'faktura-prijata-polozka')
				inv_items.append(it)
			invoice['polozkyFaktury']= inv_items
		return self.create_evidence_item('faktura-prijata',invoice)
		

	def update_vydana_faktura(self, id, invoice):
		"""Tato metoda slouzi k updatu hodnot vydane faktuy, ktera je jiz
		vedena ve Flexibee.
		Pro ukazku pouziti viz dokumentace.
		Returns :tuple consisting of (success, result, error_message)
		:param: id: id of invoice which you want to change
		:param invoice: dictionary that contains changed data
		"""
		return self.update_evidence_item(id, 'faktura-vydana', invoice)

	def update_prijata_faktura(self, id, invoice):
		return self.update_evidence_item(id, 'faktura-prijata', invoice)

	def delete_vydana_faktura(self, id):
		"""Smaze vydanou fakturu podle id.
		:param id: id faktury	
		"""
		self.delete_item(id, 'faktura-vydana')

	def delete_prijata_faktura(self, id):
		"""Smaze prijatou fakturu podle id.
		:param id: id faktury
		"""
		self.delete_item(id, 'faktura-prijata')	

	def get_vydana_faktura(self, id, detail='summary'):
		return self.get_evidence_item(id, 'faktura-vydana', detail)

	def get_vydana_faktura_by_code(self, code, detail='summary'):
		return self.get_evidence_item_by_code(code, 'faktura-vydana', detail)
			
	def get_prijata_faktura(self, id, detail='summary'):
		return self.get_evidence_item(id, 'faktura-prijata', detail)

	def get_prijata_faktura_by_code(self, code, detail='summary'):
		return self.get_evidence_item_by_code(code, 'faktura-prijata', detail)		

	def __get_faktura_pdf_url(self, faktura_typ, id):
		"""Vraci url odkaz na fakturu ve formatu pdf.
		:param faktura_typ: dve moznosti faktura-prijata, faktura-vydana
		:param id: id faktury
		"""
		server_settings = self.conf.get_server_config()
		url = str(server_settings['url'])
		return url+faktura_typ+'/'+id+'.pdf'

	def get_faktura_vydana_pdf_url(self, id):
		"""Vrati string obsahujici odkaz na pdf vydane faktury.
		:param id: Id vydane faktury
		"""
		return self.get_faktura_pdf_url('faktura-vydana',id)

	def get_faktura_prijata_pdf_url(self, id):
		"""Vrati string obsahujici odkaz na pdf prijate faktury.
		:param id: Id prijate faktury
		"""
		return self.get_faktura_pdf_url('faktura-prijata',id)	


	def get_faktura_vydana_pdf(self, id):
		"""
		Vraci pdf faktury vydane, ktera je ve Flexibee.
		:param id: id vydane faktury
		"""
		return self.get_evidence_pdf('faktura-vydana',id)



# -*- coding: utf-8 -*-

"""
This module implements the flexipy API.

:copyright: (c) 2012 by Jakub Ječmínek.
:license: BSD, see LICENSE for more details.
"""
from adresar import Adresar
from faktura import Faktura
from bank import Banka


from setuptools import setup

setup(
    name='flexipy',
    version='0.4.1',
    description='A library for communication with accounting system Flexibee.',
    packages=['flexipy'],
    license='BSD',
    author='Jakub Jecminek',
    author_email='jecmijak@gmail.com',
    keywords='flexibee accounting invoices',
    url='https://github.com/JakubJecminek/flexipy',
    include_package_data=True,
    package_data={'flexipy':['flexipy.conf','test_flexipy.conf','demo_flexibee.conf']},
    install_requires=(
         'setuptools>=0.6b1',
         'Paver==1.0.5',
         'requests',
     ),

    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',        
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',        
    ]
)



# -*- coding: utf-8 -*-

import requests
import json
from .exceptions import FlexipyException
from main import Flexipy
from config import Config


class Adresar(Flexipy):

	def __init__(self, conf=Config()):
		Flexipy.__init__(self, config=conf)

	def get_adresar(self, id, detail='summary'):
		return self.get_evidence_item(id, 'adresar', detail)

	def get_adresar_by_code(self, code, detail='summary'):
		return self.get_evidence_item_by_code(code, 'adresar', detail)			

	def update_adresar(self, id, adresar):
		"""
		Tato metoda slouzi k udpatovani obsahu polozky v adresari
		viz dokumentace
		:param id: id polozky
		:parma adresar: dictionary obsahujici zmenene polozky adresare	
		:return tuple obsahujici (success, result, error_message)
		"""
		return self.update_evidence_item(id, 'adresar', adresar)

	def delete_adresar(self, id):
		self.delete_item(id, 'adresar')		

	def create_adresar(self, kod, nazev, dalsi_param=None):
		"""Vytvori novy kontakt v adresari Flexibee. Definice evidence se 
		nachazi zde:
		http://demo.flexibee.eu/c/demo/adresar/properties
		:param kod: kod adresare
		:param dalsi_param: dalsi nepovinne parametry
		"""	
		return self.create_evidence_item('adresar',address_item)

	def create_adresar_bank_ucet(self, firma, cislo_uctu, kod_banky, dalsi_parametry=None):
		"""Vytvori pro firmu v adresari bankovni spojeni.
		:param firma: kod firmy pro kterou vytvarime bankovni spojeni
		:param cislo_uctu: cislo bankovniho uctu
		:param kod_banky: code banky 
		:dalsi_parametry: dalsi mozne parametry viz dokumentace
		"""
		#TODO#
		return self.create_evidence_item('adresar-bankovni-ucet')	